@@ -5,7 +5,7 @@ use IO::Socket::INET;
 use warnings;
 use strict;
 
-our $VERSION = '1.0.0';
+our $VERSION = '1.0.1';
 
 
 sub new {
@@ -139,7 +139,10 @@ sub set_frequency {
     my ($self, $frequency) = @_;
     my $response = $self->command("F $frequency");
 
-    if ($response ne 'RPRT 0') {
+    if (! defined($response)) {
+        return (undef);
+    }
+    elsif ($response ne 'RPRT 0') {
         $self->_set_error("Set frequency failed. Unexpected response: $response");
         return (undef);
     }
@@ -159,7 +162,10 @@ sub set_demodulator_mode {
     my ($self, $mode) = @_;
     my $response = $self->command("M $mode");
 
-    if ($response ne 'RPRT 0') {
+    if (! defined($response)) {
+        return (undef);
+    }
+    elsif ($response ne 'RPRT 0') {
         $self->_set_error("Set demodulator mode failed. Unexpected response: $response");
         return (undef);
     }
@@ -193,7 +199,10 @@ sub set_squelch_threshold {
     my ($self, $level) = @_;
     my $response = $self->command("L SQL $level");
 
-    if ($response ne 'RPRT 0') {
+    if (! defined($response)) {
+        return (undef);
+    }
+    elsif ($response ne 'RPRT 0') {
         $self->_set_error("Set demodulator mode failed. Unexpected response: $response");
         return (undef);
     }
@@ -203,22 +212,26 @@ sub set_squelch_threshold {
 
 
 sub get_recorder_status {
-   my ($self) = @_;
+    my ($self) = @_;
 
-   return ($self->command("u RECORD"));
+    return ($self->command("u RECORD"));
 }
 
 
 sub set_recorder_status {
-   my ($self, $status) = @_;
-   my $response = $self->command("U RECORD $status");
+    my ($self, $status) = @_;
+    my $response = $self->command("U RECORD $status");
 
-   if ($response ne 'RPRT 0') {
-       $self->_set_error("Failed to set recorder state.  Unexpected response: $response");
-       return (undef);
-   }
 
-   return (1);
+    if (! defined($response)) {
+        return (undef);
+    }
+    elsif ($response ne 'RPRT 0') {
+        $self->_set_error("Failed to set recorder state.  Unexpected response: $response");
+        return (undef);
+    }
+
+    return (1);
 }
 
 
@@ -226,7 +239,10 @@ sub start_recording {
     my ($self) = @_;
     my $response = $self->command("AOS");
 
-    if ($response ne 'RPRT 0') {
+    if (! defined($response)) {
+        return (undef);
+    }
+    elsif ($response ne 'RPRT 0') {
         $self->_set_error("Failed to start recording.  Unexpected response: $response");
         return (undef);
     }
@@ -239,7 +255,10 @@ sub stop_recording {
     my ($self) = @_;
     my $response = $self->command("LOS");
 
-    if ($response ne 'RPRT 0') {
+    if (! defined($response)) {
+        return (undef);
+    }
+    elsif ($response ne 'RPRT 0') {
         $self->_set_error("Failed to stop recording.  Unexpected response: $response");
         return (undef);
     }
@@ -350,7 +369,7 @@ should be captured and handled.
     $frequency = $remote->get_frequency();
 
     # To set the frequency:
-    $remote->set_frequency(4400000); # 44,000 kHz
+    $remote->set_frequency(44000000); # 44,000 kHz
 
 All frequency values are in hertz.
 
@@ -429,19 +448,19 @@ call will return C<undef>.
 
 * GQRX::Remote on GitHub:
 
-  https://github.com/DougHaber/gqrx-remote
+https://github.com/DougHaber/gqrx-remote
 
 * Example script for collecting signal strength data: (included in distribution)
 
-  https://github.com/DougHaber/gqrx-remote/blob/master/example
+https://github.com/DougHaber/gqrx-remote/blob/master/example
 
 * Gqrx:
 
-  http://gqrx.dk/
+http://gqrx.dk/
 
 * Gqrx remote control protocol documentation:
 
-  http://gqrx.dk/doc/remote-control
+http://gqrx.dk/doc/remote-control
 
 
 =head1 AUTHOR
